***********************************************************
cfr: a universal framework for climate field reconstruction
***********************************************************

`cfr` aims to provide a universal framework for climate field reconstruction (CFR).

Documentation
=============

+ Homepage: https://fzhu2e.github.io/cfr
+ Installation: https://fzhu2e.github.io/cfr/ug-installation.html